@@ -9,7 +9,7 @@ from linkml_runtime.loaders import yaml_loader
 from linkml_runtime.utils.schemaview import SchemaView
 from tests.model.kitchen_sink import Person, Dataset, FamilialRelationship
 from tests.model.kitchen_sink_api import AddPerson
-from tests import MODEL_DIR, INPUT_DIR
+from tests import MODEL_DIR, INPUT_DIR, OUTPUT_DIR
 
 SCHEMA = os.path.join(MODEL_DIR, 'kitchen_sink.yaml')
 API_SCHEMA = os.path.join(MODEL_DIR, 'kitchen_sink_api_test.yaml')
@@ -32,9 +32,9 @@ class ApiGeneratorTestCase(unittest.TestCase):
         with open(API_SCHEMA, 'w') as stream:
             stream.write(gen.serialize())
         api_view = SchemaView(API_SCHEMA)
-        for cn, c in api_view.all_class().items():
+        for cn, c in api_view.all_classes().items():
             logging.info(f'C={cn}')
-        assert 'AddPerson' in api_view.all_class()
+        assert 'AddPerson' in api_view.all_classes()
 
 
 if __name__ == '__main__':
